[gnome-software: 14/110] Hdy → Adw




commit 329278d71241887d44a7f0c3759ae7ee68f39d91
Author: Georges Basile Stavracas Neto <georges stavracas gmail com>
Date:   Sat Aug 21 14:09:16 2021 -0300

    Hdy → Adw
    
    This is simply a massive find & replace, where all Hdy instances
    are converted to Adw. No APIs were adapted.

 src/gs-age-rating-context-dialog.c        |  2 +-
 src/gs-age-rating-context-dialog.ui       |  4 ++--
 src/gs-app-context-bar.c                  |  2 +-
 src/gs-app-details-page.c                 | 10 ++++----
 src/gs-app-details-page.ui                |  2 +-
 src/gs-app-translation-dialog.c           |  2 +-
 src/gs-app-translation-dialog.ui          |  4 ++--
 src/gs-app-version-history-dialog.ui      |  4 ++--
 src/gs-application.c                      |  4 ++--
 src/gs-category-page.ui                   |  2 +-
 src/gs-details-page.c                     | 18 +++++++-------
 src/gs-details-page.ui                    | 34 +++++++++++++-------------
 src/gs-extras-page.ui                     |  2 +-
 src/gs-featured-carousel.c                | 16 ++++++-------
 src/gs-featured-carousel.ui               |  4 ++--
 src/gs-first-run-dialog.c                 |  6 ++---
 src/gs-first-run-dialog.h                 |  4 ++--
 src/gs-first-run-dialog.ui                |  6 ++---
 src/gs-hardware-support-context-dialog.c  |  2 +-
 src/gs-hardware-support-context-dialog.ui |  4 ++--
 src/gs-info-window.c                      |  6 ++---
 src/gs-info-window.h                      |  6 ++---
 src/gs-info-window.ui                     |  4 ++--
 src/gs-installed-page.ui                  | 10 ++++----
 src/gs-loading-page.c                     |  2 +-
 src/gs-loading-page.ui                    |  8 +++----
 src/gs-moderate-page.ui                   |  2 +-
 src/gs-os-update-page.c                   | 10 ++++----
 src/gs-os-update-page.ui                  |  6 ++---
 src/gs-overview-page.c                    |  2 +-
 src/gs-overview-page.ui                   |  2 +-
 src/gs-picture.c                          |  4 ++--
 src/gs-prefs-dialog.c                     |  4 ++--
 src/gs-prefs-dialog.h                     |  4 ++--
 src/gs-prefs-dialog.ui                    | 10 ++++----
 src/gs-repos-dialog.c                     | 34 +++++++++++++-------------
 src/gs-repos-dialog.h                     |  4 ++--
 src/gs-repos-dialog.ui                    |  8 +++----
 src/gs-repos-section.c                    |  4 ++--
 src/gs-repos-section.h                    |  4 ++--
 src/gs-rounded-bin.c                      |  2 +-
 src/gs-safety-context-dialog.c            |  2 +-
 src/gs-safety-context-dialog.ui           |  6 ++---
 src/gs-screenshot-carousel.c              | 26 ++++++++++----------
 src/gs-screenshot-carousel.ui             |  4 ++--
 src/gs-search-page.ui                     |  6 ++---
 src/gs-shell.c                            | 40 +++++++++++++++----------------
 src/gs-shell.h                            |  4 ++--
 src/gs-shell.ui                           | 22 ++++++++---------
 src/gs-storage-context-dialog.c           |  2 +-
 src/gs-storage-context-dialog.ui          |  4 ++--
 src/gs-update-dialog.c                    | 22 ++++++++---------
 src/gs-update-dialog.h                    |  4 ++--
 src/gs-update-dialog.ui                   | 12 +++++-----
 src/gs-updates-page.c                     | 10 ++++----
 src/gs-updates-page.ui                    | 22 ++++++++---------
 src/gtk-style.css                         | 22 ++++++++---------
 57 files changed, 238 insertions(+), 238 deletions(-)
---
diff --git a/src/gs-age-rating-context-dialog.c b/src/gs-age-rating-context-dialog.c
index 135db46e4..94d1be57c 100644
--- a/src/gs-age-rating-context-dialog.c
+++ b/src/gs-age-rating-context-dialog.c
@@ -29,11 +29,11 @@
 
 #include "config.h"
 
+#include <adwaita.h>
 #include <glib.h>
 #include <glib-object.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <handy.h>
 #include <locale.h>
 
 #include "gs-app.h"
diff --git a/src/gs-age-rating-context-dialog.ui b/src/gs-age-rating-context-dialog.ui
index 52a60e7e7..d462d81dd 100644
--- a/src/gs-age-rating-context-dialog.ui
+++ b/src/gs-age-rating-context-dialog.ui
@@ -4,10 +4,10 @@
   <template class="GsAgeRatingContextDialog" parent="GsInfoWindow">
     <property name="title" translatable="yes" comments="Translators: This is the title of the dialog which 
contains information about the suitability of an app for different ages.">Age Rating</property>
     <child>
-      <object class="HdyPreferencesPage">
+      <object class="AdwPreferencesPage">
         <property name="visible">True</property>
         <child>
-          <object class="HdyPreferencesGroup">
+          <object class="AdwPreferencesGroup">
             <property name="visible">True</property>
 
             <child>
diff --git a/src/gs-app-context-bar.c b/src/gs-app-context-bar.c
index da5f23ec1..79279f4ad 100644
--- a/src/gs-app-context-bar.c
+++ b/src/gs-app-context-bar.c
@@ -26,11 +26,11 @@
 
 #include "config.h"
 
+#include <adwaita.h>
 #include <glib.h>
 #include <glib-object.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <handy.h>
 #include <locale.h>
 
 #include "gs-age-rating-context-dialog.h"
diff --git a/src/gs-app-details-page.c b/src/gs-app-details-page.c
index 513522469..79fe76ef0 100644
--- a/src/gs-app-details-page.c
+++ b/src/gs-app-details-page.c
@@ -20,8 +20,8 @@
 
 #include "config.h"
 
+#include <adwaita.h>
 #include <glib/gi18n.h>
-#include <handy.h>
 
 #include "gs-app-details-page.h"
 #include "gs-app-row.h"
@@ -145,7 +145,7 @@ set_updates_description_ui (GsAppDetailsPage *page, GsApp *app)
        kind = gs_app_get_kind (app);
        if (kind == AS_COMPONENT_KIND_GENERIC &&
            gs_app_get_special_kind (app) == GS_APP_SPECIAL_KIND_OS_UPDATE) {
-               hdy_header_bar_set_title (HDY_HEADER_BAR (page->header_bar),
+               adw_header_bar_set_title (ADW_HEADER_BAR (page->header_bar),
                                          gs_app_get_name (app));
        } else if (gs_app_get_source_default (app) != NULL &&
                   gs_app_get_update_version (app) != NULL) {
@@ -159,12 +159,12 @@ set_updates_description_ui (GsAppDetailsPage *page, GsApp *app)
                tmp = g_strdup_printf (_("%s %s"),
                                       gs_app_get_source_default (app),
                                       gs_app_get_update_version (app));
-               hdy_header_bar_set_title (HDY_HEADER_BAR (page->header_bar), tmp);
+               adw_header_bar_set_title (ADW_HEADER_BAR (page->header_bar), tmp);
        } else if (gs_app_get_source_default (app) != NULL) {
-               hdy_header_bar_set_title (HDY_HEADER_BAR (page->header_bar),
+               adw_header_bar_set_title (ADW_HEADER_BAR (page->header_bar),
                                          gs_app_get_source_default (app));
        } else {
-               hdy_header_bar_set_title (HDY_HEADER_BAR (page->header_bar),
+               adw_header_bar_set_title (ADW_HEADER_BAR (page->header_bar),
                                          gs_app_get_update_version (app));
        }
 
diff --git a/src/gs-app-details-page.ui b/src/gs-app-details-page.ui
index 1049d75a0..6fe690846 100644
--- a/src/gs-app-details-page.ui
+++ b/src/gs-app-details-page.ui
@@ -5,7 +5,7 @@
     <property name="orientation">vertical</property>
 
     <child>
-      <object class="HdyHeaderBar" id="header_bar">
+      <object class="AdwHeaderBar" id="header_bar">
         <property name="show_close_button">True</property>
         <property name="visible">True</property>
         <child>
diff --git a/src/gs-app-translation-dialog.c b/src/gs-app-translation-dialog.c
index b96ac1dc3..1f41eccee 100644
--- a/src/gs-app-translation-dialog.c
+++ b/src/gs-app-translation-dialog.c
@@ -27,11 +27,11 @@
 
 #include "config.h"
 
+#include <adwaita.h>
 #include <glib.h>
 #include <glib-object.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <handy.h>
 #include <locale.h>
 
 #include "gs-app.h"
diff --git a/src/gs-app-translation-dialog.ui b/src/gs-app-translation-dialog.ui
index e8f536798..157130cf4 100644
--- a/src/gs-app-translation-dialog.ui
+++ b/src/gs-app-translation-dialog.ui
@@ -4,10 +4,10 @@
   <template class="GsAppTranslationDialog" parent="GsInfoWindow">
     <property name="title" translatable="yes">Translations</property>
     <child>
-      <object class="HdyPreferencesPage">
+      <object class="AdwPreferencesPage">
         <property name="visible">True</property>
         <child>
-          <object class="HdyPreferencesGroup">
+          <object class="AdwPreferencesGroup">
             <property name="visible">True</property>
 
             <child>
diff --git a/src/gs-app-version-history-dialog.ui b/src/gs-app-version-history-dialog.ui
index ede850ad2..c25c45cef 100644
--- a/src/gs-app-version-history-dialog.ui
+++ b/src/gs-app-version-history-dialog.ui
@@ -10,7 +10,7 @@
     <property name="height_request">400</property>
     <property name="use_header_bar">1</property>
     <child internal-child="headerbar">
-      <object class="HdyHeaderBar"/>
+      <object class="AdwHeaderBar"/>
     </child>
     <child internal-child="vbox">
       <object class="GtkBox">
@@ -21,7 +21,7 @@
           <object class="GtkScrolledWindow">
             <property name="visible">True</property>
             <child>
-              <object class="HdyClamp">
+              <object class="AdwClamp">
                 <property name="visible">True</property>
                 <property name="vexpand">True</property>
                 <property name="hexpand">False</property>
diff --git a/src/gs-application.c b/src/gs-application.c
index 90487df62..78102cb10 100644
--- a/src/gs-application.c
+++ b/src/gs-application.c
@@ -13,10 +13,10 @@
 #include "gs-application.h"
 
 #include <stdlib.h>
+#include <adwaita.h>
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 #include <gio/gdesktopappinfo.h>
-#include <handy.h>
 #include <libsoup/soup.h>
 
 #ifdef GDK_WINDOWING_X11
@@ -1030,7 +1030,7 @@ gs_application_startup (GApplication *application)
        GsApplication *app = GS_APPLICATION (application);
        G_APPLICATION_CLASS (gs_application_parent_class)->startup (application);
 
-       hdy_init ();
+       adw_init ();
 
        gs_application_add_wrapper_actions (application);
 
diff --git a/src/gs-category-page.ui b/src/gs-category-page.ui
index e5e4d1fdc..f504aaa51 100644
--- a/src/gs-category-page.ui
+++ b/src/gs-category-page.ui
@@ -13,7 +13,7 @@
           <object class="GtkViewport" id="viewport3">
             <property name="visible">True</property>
             <child>
-              <object class="HdyClamp">
+              <object class="AdwClamp">
                 <property name="visible">True</property>
                 <!-- We use the same sizes as the overview page. -->
                 <property name="maximum-size">1000</property>
diff --git a/src/gs-details-page.c b/src/gs-details-page.c
index 9fa7b1848..550037724 100644
--- a/src/gs-details-page.c
+++ b/src/gs-details-page.c
@@ -103,11 +103,11 @@ struct _GsDetailsPage
        GtkWidget               *button_details_add_shortcut;
        GtkWidget               *button_details_remove_shortcut;
        GtkStack                *links_stack;
-       HdyActionRow            *project_website_row;
-       HdyActionRow            *donate_row;
-       HdyActionRow            *translate_row;
-       HdyActionRow            *report_an_issue_row;
-       HdyActionRow            *help_row;
+       AdwActionRow            *project_website_row;
+       AdwActionRow            *donate_row;
+       AdwActionRow            *translate_row;
+       AdwActionRow            *report_an_issue_row;
+       AdwActionRow            *help_row;
        GtkWidget               *button_install;
        GtkWidget               *button_update;
        GtkWidget               *button_remove;
@@ -514,9 +514,9 @@ gs_details_page_notify_state_changed_cb (GsApp *app,
 }
 
 static void
-gs_details_page_link_row_activated_cb (HdyActionRow *row, GsDetailsPage *self)
+gs_details_page_link_row_activated_cb (AdwActionRow *row, GsDetailsPage *self)
 {
-       gs_shell_show_uri (self->shell, hdy_action_row_get_subtitle (row));
+       gs_shell_show_uri (self->shell, adw_action_row_get_subtitle (row));
 }
 
 static void
@@ -953,13 +953,13 @@ gs_details_page_refresh_buttons (GsDetailsPage *self)
 }
 
 static gboolean
-update_action_row_from_link (HdyActionRow *row,
+update_action_row_from_link (AdwActionRow *row,
                              GsApp        *app,
                              AsUrlKind     url_kind)
 {
        const gchar *url = gs_app_get_url (app, url_kind);
        if (url != NULL)
-               hdy_action_row_set_subtitle (row, url);
+               adw_action_row_set_subtitle (row, url);
        gtk_widget_set_visible (GTK_WIDGET (row), url != NULL);
 
        return (url != NULL);
diff --git a/src/gs-details-page.ui b/src/gs-details-page.ui
index 4dfe50530..c8b21d39f 100644
--- a/src/gs-details-page.ui
+++ b/src/gs-details-page.ui
@@ -112,7 +112,7 @@
                           <class name="details-page"/>
                         </style>
                         <child>
-                          <object class="HdyClamp">
+                          <object class="AdwClamp">
                             <property name="visible">True</property>
                             <property name="maximum-size">860</property>
                             <!-- ~⅔ of the maximum size. -->
@@ -395,7 +395,7 @@
                         </child>
 
                         <child>
-                          <object class="HdyClamp">
+                          <object class="AdwClamp">
                             <property name="visible">True</property>
                             <property name="maximum-size">860</property>
                             <!-- ~⅔ of the maximum size. -->
@@ -439,7 +439,7 @@
                         </child>
 
                         <child>
-                          <object class="HdyClamp">
+                          <object class="AdwClamp">
                             <property name="visible">True</property>
                             <property name="maximum-size">860</property>
                             <!-- ~⅔ of the maximum size. -->
@@ -497,7 +497,7 @@
                         </child>
 
                         <child>
-                          <object class="HdyClamp">
+                          <object class="AdwClamp">
                             <property name="visible">True</property>
                             <property name="maximum-size">860</property>
                             <!-- ~⅔ of the maximum size. -->
@@ -513,7 +513,7 @@
                         </child>
 
                         <child>
-                          <object class="HdyClamp">
+                          <object class="AdwClamp">
                             <property name="visible">True</property>
                             <property name="maximum-size">860</property>
                             <!-- ~⅔ of the maximum size. -->
@@ -569,7 +569,7 @@
                         </child>
 
                         <child>
-                          <object class="HdyClamp">
+                          <object class="AdwClamp">
                             <property name="visible" bind-source="label_webapp_warning" 
bind-property="visible" bind-flags="sync-create"/>
                             <property name="maximum-size">860</property>
                             <!-- ~⅔ of the maximum size. -->
@@ -593,7 +593,7 @@
                         </child>
 
                         <child>
-                          <object class="HdyClamp">
+                          <object class="AdwClamp">
                             <property name="visible" bind-source="infobar_details_app_repo" 
bind-property="visible" bind-flags="sync-create"/>
                             <property name="maximum-size">860</property>
                             <!-- ~⅔ of the maximum size. -->
@@ -612,7 +612,7 @@
                         </child>
 
                         <child>
-                          <object class="HdyClamp">
+                          <object class="AdwClamp">
                             <property name="visible" bind-source="infobar_details_app_norepo" 
bind-property="visible" bind-flags="sync-create"/>
                             <property name="maximum-size">860</property>
                             <!-- ~⅔ of the maximum size. -->
@@ -631,7 +631,7 @@
                         </child>
 
                         <child>
-                          <object class="HdyClamp">
+                          <object class="AdwClamp">
                             <property name="visible" bind-source="infobar_details_package_baseos" 
bind-property="visible" bind-flags="sync-create"/>
                             <property name="maximum-size">860</property>
                             <!-- ~⅔ of the maximum size. -->
@@ -650,7 +650,7 @@
                         </child>
 
                         <child>
-                          <object class="HdyClamp">
+                          <object class="AdwClamp">
                             <property name="visible" bind-source="infobar_details_repo" 
bind-property="visible" bind-flags="sync-create"/>
                             <property name="maximum-size">860</property>
                             <!-- ~⅔ of the maximum size. -->
@@ -670,7 +670,7 @@
                         </child>
 
                         <child>
-                          <object class="HdyClamp">
+                          <object class="AdwClamp">
                             <property name="visible">True</property>
                             <property name="maximum-size">860</property>
                             <!-- ~⅔ of the maximum size. -->
@@ -763,7 +763,7 @@
                                         </style>
 
                                         <child>
-                                          <object class="HdyActionRow" id="project_website_row">
+                                          <object class="AdwActionRow" id="project_website_row">
                                             <property name="activatable">True</property>
                                             <property name="visible">True</property>
                                             <property name="title" translatable="yes">Project 
_Website</property>
@@ -789,7 +789,7 @@
                                         </child>
 
                                         <child>
-                                          <object class="HdyActionRow" id="donate_row">
+                                          <object class="AdwActionRow" id="donate_row">
                                             <property name="activatable">True</property>
                                             <property name="visible">True</property>
                                             <property name="title" translatable="yes">_Donate</property>
@@ -815,7 +815,7 @@
                                         </child>
 
                                         <child>
-                                          <object class="HdyActionRow" id="translate_row">
+                                          <object class="AdwActionRow" id="translate_row">
                                             <property name="activatable">True</property>
                                             <property name="visible">True</property>
                                             <property name="title" translatable="yes">Contribute 
_Translations</property>
@@ -841,7 +841,7 @@
                                         </child>
 
                                         <child>
-                                          <object class="HdyActionRow" id="report_an_issue_row">
+                                          <object class="AdwActionRow" id="report_an_issue_row">
                                             <property name="activatable">True</property>
                                             <property name="visible">True</property>
                                             <property name="title" translatable="yes">_Report an 
Issue</property>
@@ -867,7 +867,7 @@
                                         </child>
 
                                         <child>
-                                          <object class="HdyActionRow" id="help_row">
+                                          <object class="AdwActionRow" id="help_row">
                                             <property name="activatable">True</property>
                                             <property name="visible">True</property>
                                             <property name="title" translatable="yes">_Help</property>
@@ -904,7 +904,7 @@
                         </child>
 
                         <child>
-                          <object class="HdyClamp">
+                          <object class="AdwClamp">
                             <property name="visible" bind-source="box_reviews" bind-property="visible" 
bind-flags="sync-create"/>
                             <property name="maximum-size">860</property>
                             <!-- ~⅔ of the maximum size. -->
diff --git a/src/gs-extras-page.ui b/src/gs-extras-page.ui
index 3d9ada3e2..c11aa9c74 100644
--- a/src/gs-extras-page.ui
+++ b/src/gs-extras-page.ui
@@ -46,7 +46,7 @@
             <property name="vscrollbar_policy">automatic</property>
             <property name="shadow_type">none</property>
             <child>
-              <object class="HdyClamp">
+              <object class="AdwClamp">
                 <property name="visible">True</property>
                 <property name="maximum-size">860</property>
                 <!-- ~⅔ of the maximum size. -->
diff --git a/src/gs-featured-carousel.ui b/src/gs-featured-carousel.ui
index 1c2f8b790..d416c2a44 100644
--- a/src/gs-featured-carousel.ui
+++ b/src/gs-featured-carousel.ui
@@ -21,7 +21,7 @@
           <object class="GsRoundedBin">
             <property name="visible">True</property>
             <child>
-              <object class="HdyCarousel" id="carousel">
+              <object class="AdwCarousel" id="carousel">
                 <property name="visible">True</property>
               </object>
             </child>
@@ -90,7 +90,7 @@
       </object>
     </child>
     <child>
-      <object class="HdyCarouselIndicatorDots" id="dots">
+      <object class="AdwCarouselIndicatorDots" id="dots">
         <property name="carousel">carousel</property>
         <property name="visible">True</property>
       </object>
diff --git a/src/gs-first-run-dialog.c b/src/gs-first-run-dialog.c
index 923cf5fef..3b771ef8d 100644
--- a/src/gs-first-run-dialog.c
+++ b/src/gs-first-run-dialog.c
@@ -14,17 +14,17 @@
 
 struct _GsFirstRunDialog
 {
-       HdyWindow        parent_instance;
+       AdwWindow        parent_instance;
 
        GtkWidget       *button;
 };
 
-G_DEFINE_TYPE (GsFirstRunDialog, gs_first_run_dialog, HDY_TYPE_WINDOW)
+G_DEFINE_TYPE (GsFirstRunDialog, gs_first_run_dialog, ADW_TYPE_WINDOW)
 
 static gboolean
 key_press_event_cb (GtkWidget            *sender,
                     GdkEvent             *event,
-                    HdyPreferencesWindow *self)
+                    AdwPreferencesWindow *self)
 {
        guint keyval;
        GdkModifierType state;
diff --git a/src/gs-first-run-dialog.h b/src/gs-first-run-dialog.h
index 1254e0c2b..fb5083d69 100644
--- a/src/gs-first-run-dialog.h
+++ b/src/gs-first-run-dialog.h
@@ -8,14 +8,14 @@
 
 #pragma once
 
+#include <adwaita.h>
 #include <gtk/gtk.h>
-#include <handy.h>
 
 G_BEGIN_DECLS
 
 #define GS_TYPE_FIRST_RUN_DIALOG (gs_first_run_dialog_get_type ())
 
-G_DECLARE_FINAL_TYPE (GsFirstRunDialog, gs_first_run_dialog, GS, FIRST_RUN_DIALOG, HdyWindow)
+G_DECLARE_FINAL_TYPE (GsFirstRunDialog, gs_first_run_dialog, GS, FIRST_RUN_DIALOG, AdwWindow)
 
 GtkWidget      *gs_first_run_dialog_new        (void);
 
diff --git a/src/gs-first-run-dialog.ui b/src/gs-first-run-dialog.ui
index 4db6cbfaa..eb9533621 100644
--- a/src/gs-first-run-dialog.ui
+++ b/src/gs-first-run-dialog.ui
@@ -2,7 +2,7 @@
 <!-- Generated with glade 3.18.1 -->
 <interface>
   <requires lib="gtk+" version="3.12"/>
-  <template class="GsFirstRunDialog" parent="HdyWindow">
+  <template class="GsFirstRunDialog" parent="AdwWindow">
     <property name="modal">True</property>
     <property name="window_position">center</property>
     <property name="destroy_with_parent">True</property>
@@ -18,10 +18,10 @@
     </style>
 
     <child>
-      <object class="HdyWindowHandle">
+      <object class="AdwWindowHandle">
         <property name="visible">True</property>
         <child>
-          <object class="HdyStatusPage">
+          <object class="AdwStatusPage">
             <property name="visible">True</property>
             <property name="icon_name">org.gnome.Software</property>
             <property name="title" translatable="yes">Welcome to Software</property>
diff --git a/src/gs-hardware-support-context-dialog.c b/src/gs-hardware-support-context-dialog.c
index 3ebb907f3..6361ddb17 100644
--- a/src/gs-hardware-support-context-dialog.c
+++ b/src/gs-hardware-support-context-dialog.c
@@ -29,11 +29,11 @@
 
 #include "config.h"
 
+#include <adwaita.h>
 #include <glib.h>
 #include <glib-object.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <handy.h>
 #include <locale.h>
 
 #include "gs-app.h"
diff --git a/src/gs-hardware-support-context-dialog.ui b/src/gs-hardware-support-context-dialog.ui
index cab86c778..c65321079 100644
--- a/src/gs-hardware-support-context-dialog.ui
+++ b/src/gs-hardware-support-context-dialog.ui
@@ -4,10 +4,10 @@
   <template class="GsHardwareSupportContextDialog" parent="GsInfoWindow">
     <property name="title" translatable="yes" comments="Translators: This is the title of the dialog which 
contains information about the hardware support/requirements of an app">Hardware Support</property>
     <child>
-      <object class="HdyPreferencesPage">
+      <object class="AdwPreferencesPage">
         <property name="visible">True</property>
         <child>
-          <object class="HdyPreferencesGroup">
+          <object class="AdwPreferencesGroup">
             <property name="visible">True</property>
 
             <child>
diff --git a/src/gs-info-window.c b/src/gs-info-window.c
index c91731bc6..d8ff4ff39 100644
--- a/src/gs-info-window.c
+++ b/src/gs-info-window.c
@@ -25,7 +25,7 @@
 #include <glib-object.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <handy.h>
+#include <adwaita.h>
 #include <locale.h>
 
 #include "gs-common.h"
@@ -39,12 +39,12 @@ typedef struct
 } GsInfoWindowPrivate;
 
 
-G_DEFINE_TYPE_WITH_PRIVATE (GsInfoWindow, gs_info_window, HDY_TYPE_WINDOW)
+G_DEFINE_TYPE_WITH_PRIVATE (GsInfoWindow, gs_info_window, ADW_TYPE_WINDOW)
 
 static gboolean
 key_press_event_cb (GtkWidget            *sender,
                     GdkEvent             *event,
-                    HdyPreferencesWindow *self)
+                    AdwPreferencesWindow *self)
 {
        guint keyval;
        GdkModifierType state;
diff --git a/src/gs-info-window.h b/src/gs-info-window.h
index b303737a0..7a12207e2 100644
--- a/src/gs-info-window.h
+++ b/src/gs-info-window.h
@@ -13,17 +13,17 @@
 #include <glib.h>
 #include <glib-object.h>
 #include <gtk/gtk.h>
-#include <handy.h>
+#include <adwaita.h>
 
 G_BEGIN_DECLS
 
 #define GS_TYPE_INFO_WINDOW (gs_info_window_get_type ())
 
-G_DECLARE_DERIVABLE_TYPE (GsInfoWindow, gs_info_window, GS, INFO_WINDOW, HdyWindow)
+G_DECLARE_DERIVABLE_TYPE (GsInfoWindow, gs_info_window, GS, INFO_WINDOW, AdwWindow)
 
 struct _GsInfoWindowClass
 {
-       HdyWindowClass   parent_class;
+       AdwWindowClass   parent_class;
 };
 
 GsInfoWindow   *gs_info_window_new     (void);
diff --git a/src/gs-info-window.ui b/src/gs-info-window.ui
index a96862107..8b783daef 100644
--- a/src/gs-info-window.ui
+++ b/src/gs-info-window.ui
@@ -1,7 +1,7 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <interface>
   <requires lib="gtk+" version="3.10"/>
-  <template class="GsInfoWindow" parent="HdyWindow">
+  <template class="GsInfoWindow" parent="AdwWindow">
     <property name="modal">True</property>
     <property name="window_position">center</property>
     <property name="destroy_with_parent">True</property>
@@ -18,7 +18,7 @@
       <object class="GtkOverlay" id="overlay">
         <property name="visible">True</property>
         <child type="overlay">
-          <object class="HdyHeaderBar">
+          <object class="AdwHeaderBar">
             <property name="show_close_button">True</property>
             <property name="visible">True</property>
             <property name="valign">start</property>
diff --git a/src/gs-installed-page.ui b/src/gs-installed-page.ui
index 7a1ea935e..b82cfc5c6 100644
--- a/src/gs-installed-page.ui
+++ b/src/gs-installed-page.ui
@@ -40,7 +40,7 @@
                   <class name="list-page"/>
                 </style>
                 <child>
-                  <object class="HdyClamp">
+                  <object class="AdwClamp">
                     <property name="visible">True</property>
                     <property name="maximum-size">600</property>
                     <property name="tightening-threshold">400</property>
@@ -49,7 +49,7 @@
                         <property name="visible">True</property>
                         <property name="orientation">vertical</property>
                         <child>
-                          <object class="HdyPreferencesGroup" id="group_install_in_progress">
+                          <object class="AdwPreferencesGroup" id="group_install_in_progress">
                             <property name="visible">False</property>
                             <property name="title" translatable="yes">In Progress</property>
                             <style>
@@ -71,7 +71,7 @@
                           </object>
                         </child>
                         <child>
-                          <object class="HdyPreferencesGroup" id="group_install_apps">
+                          <object class="AdwPreferencesGroup" id="group_install_apps">
                             <property name="visible">False</property>
                             <property name="title" translatable="yes">Applications</property>
                             <style>
@@ -93,7 +93,7 @@
                           </object>
                         </child>
                         <child>
-                          <object class="HdyPreferencesGroup" id="group_install_system_apps">
+                          <object class="AdwPreferencesGroup" id="group_install_system_apps">
                             <property name="visible">False</property>
                             <property name="title" translatable="yes">System Applications</property>
                             <style>
@@ -115,7 +115,7 @@
                           </object>
                         </child>
                         <child>
-                          <object class="HdyPreferencesGroup" id="group_install_addons">
+                          <object class="AdwPreferencesGroup" id="group_install_addons">
                             <property name="visible">False</property>
                             <property name="title" translatable="yes">Add-ons</property>
                             <style>
diff --git a/src/gs-loading-page.c b/src/gs-loading-page.c
index 82fb9ff91..8584ebbb2 100644
--- a/src/gs-loading-page.c
+++ b/src/gs-loading-page.c
@@ -67,7 +67,7 @@ gs_loading_page_status_changed_cb (GsPluginLoader *plugin_loader,
        }
 
        /* update title */
-       hdy_status_page_set_title (HDY_STATUS_PAGE (priv->status_page), str);
+       adw_status_page_set_title (ADW_STATUS_PAGE (priv->status_page), str);
 
        /* update progresbar */
        if (app != NULL) {
diff --git a/src/gs-loading-page.ui b/src/gs-loading-page.ui
index fb631f54a..bf8acdd7a 100644
--- a/src/gs-loading-page.ui
+++ b/src/gs-loading-page.ui
@@ -8,7 +8,7 @@
       </object>
     </child>
     <child>
-      <object class="HdyStatusPage" id="status_page">
+      <object class="AdwStatusPage" id="status_page">
         <property name="visible">True</property>
         <property name="icon_name">org.gnome.Software</property>
         <property name="title" translatable="yes">Starting up…</property>
@@ -16,10 +16,10 @@
           <class name="icon-dropshadow"/>
         </style>
         <child>
-          <object class="HdyClamp">
+          <object class="AdwClamp">
             <property name="visible">True</property>
-            <!-- We explicitly want to use the default HdyClamp sizes here, as
-                 does HdyStatusPage. -->
+            <!-- We explicitly want to use the default AdwClamp sizes here, as
+                 does AdwStatusPage. -->
             <child>
               <object class="GtkProgressBar" id="progressbar">
                 <property name="visible">True</property>
diff --git a/src/gs-moderate-page.ui b/src/gs-moderate-page.ui
index 65b81c1e2..9a6dbfd4d 100644
--- a/src/gs-moderate-page.ui
+++ b/src/gs-moderate-page.ui
@@ -37,7 +37,7 @@
                 <property name="vexpand">True</property>
                 <property name="shadow_type">none</property>
                 <child>
-                  <object class="HdyClamp">
+                  <object class="AdwClamp">
                     <property name="visible">True</property>
                     <property name="maximum-size">860</property>
                     <!-- ~⅔ of the maximum size. -->
diff --git a/src/gs-os-update-page.c b/src/gs-os-update-page.c
index f43e57454..4e13aead3 100644
--- a/src/gs-os-update-page.c
+++ b/src/gs-os-update-page.c
@@ -20,8 +20,8 @@
 
 #include "config.h"
 
+#include <adwaita.h>
 #include <glib/gi18n.h>
-#include <handy.h>
 
 #include "gs-os-update-page.h"
 #include "gs-common.h"
@@ -404,9 +404,9 @@ gs_os_update_page_set_app (GsOsUpdatePage *page, GsApp *app)
        }
 
        if (app) {
-               hdy_header_bar_set_title (HDY_HEADER_BAR (page->header_bar),
+               adw_header_bar_set_title (ADW_HEADER_BAR (page->header_bar),
                                          gs_app_get_name (app));
-               hdy_preferences_group_set_description (HDY_PREFERENCES_GROUP (page->group),
+               adw_preferences_group_set_description (ADW_PREFERENCES_GROUP (page->group),
                                                       gs_app_get_description (app));
 
                /* add new apps */
@@ -422,8 +422,8 @@ gs_os_update_page_set_app (GsOsUpdatePage *page, GsApp *app)
                        gtk_list_box_insert (GTK_LIST_BOX (page->list_boxes[section]), row, -1);
                }
        } else {
-               hdy_header_bar_set_title (HDY_HEADER_BAR (page->header_bar), NULL);
-               hdy_preferences_group_set_description (HDY_PREFERENCES_GROUP (page->group), NULL);
+               adw_header_bar_set_title (ADW_HEADER_BAR (page->header_bar), NULL);
+               adw_preferences_group_set_description (ADW_PREFERENCES_GROUP (page->group), NULL);
        }
 
        g_object_notify_by_pspec (G_OBJECT (page), obj_props[PROP_APP]);
diff --git a/src/gs-os-update-page.ui b/src/gs-os-update-page.ui
index 8868bfacf..77b3ca7df 100644
--- a/src/gs-os-update-page.ui
+++ b/src/gs-os-update-page.ui
@@ -5,16 +5,16 @@
     <property name="orientation">vertical</property>
 
     <child>
-      <object class="HdyHeaderBar" id="header_bar">
+      <object class="AdwHeaderBar" id="header_bar">
         <property name="show_close_button">True</property>
         <property name="visible">True</property>
       </object>
     </child>
     <child>
-      <object class="HdyPreferencesPage">
+      <object class="AdwPreferencesPage">
         <property name="visible">True</property>
         <child>
-          <object class="HdyPreferencesGroup" id="group">
+          <object class="AdwPreferencesGroup" id="group">
             <property name="visible">True</property>
             <child>
               <object class="GtkBox" id="box">
diff --git a/src/gs-overview-page.c b/src/gs-overview-page.c
index 9ba33fb2b..70c604e5a 100644
--- a/src/gs-overview-page.c
+++ b/src/gs-overview-page.c
@@ -9,8 +9,8 @@
 
 #include "config.h"
 
+#include <adwaita.h>
 #include <glib/gi18n.h>
-#include <handy.h>
 #include <math.h>
 
 #include "gs-shell.h"
diff --git a/src/gs-overview-page.ui b/src/gs-overview-page.ui
index 8cc16233d..4aa91822d 100644
--- a/src/gs-overview-page.ui
+++ b/src/gs-overview-page.ui
@@ -71,7 +71,7 @@
                     <property name="hexpand">True</property>
                     <property name="vexpand">True</property>
                     <child>
-                      <object class="HdyClamp">
+                      <object class="AdwClamp">
                         <property name="visible">True</property>
                         <!-- We use the same sizes as the category page. -->
                         <property name="maximum-size">1000</property>
diff --git a/src/gs-picture.c b/src/gs-picture.c
index 75ac34729..492943226 100644
--- a/src/gs-picture.c
+++ b/src/gs-picture.c
@@ -83,7 +83,7 @@ gs_picture_set_pixbuf (GsPicture *picture, GdkPixbuf *pixbuf)
        g_object_notify_by_pspec (G_OBJECT (picture), obj_props[PROP_PIXBUF]);
 }
 
-/* This is derived from the private hdy_css_measure() from Libhandy. */
+/* This is derived from the private adw_css_measure() from Libhandy. */
 static void
 css_measure (GtkWidget *widget, GtkOrientation orientation, gint *minimum, gint *natural)
 {
@@ -229,7 +229,7 @@ gs_picture_get_preferred_height (GtkWidget  *widget,
                            minimum, natural, NULL, NULL);
 }
 
-/* This is derived from the private hdy_css_size_allocate_self() from Libhandy. */
+/* This is derived from the private adw_css_size_allocate_self() from Libhandy. */
 static void
 css_size_allocate_self (GtkWidget *widget, GtkAllocation *allocation)
 {
diff --git a/src/gs-prefs-dialog.c b/src/gs-prefs-dialog.c
index b49ed7ff4..3c24dba0e 100644
--- a/src/gs-prefs-dialog.c
+++ b/src/gs-prefs-dialog.c
@@ -18,7 +18,7 @@
 
 struct _GsPrefsDialog
 {
-       HdyPreferencesWindow     parent_instance;
+       AdwPreferencesWindow     parent_instance;
        GSettings               *settings;
 
        GCancellable            *cancellable;
@@ -27,7 +27,7 @@ struct _GsPrefsDialog
        GtkWidget               *switch_updates_notify;
 };
 
-G_DEFINE_TYPE (GsPrefsDialog, gs_prefs_dialog, HDY_TYPE_PREFERENCES_WINDOW)
+G_DEFINE_TYPE (GsPrefsDialog, gs_prefs_dialog, ADW_TYPE_PREFERENCES_WINDOW)
 
 static void
 gs_prefs_dialog_dispose (GObject *object)
diff --git a/src/gs-prefs-dialog.h b/src/gs-prefs-dialog.h
index f25b30255..207ba2634 100644
--- a/src/gs-prefs-dialog.h
+++ b/src/gs-prefs-dialog.h
@@ -8,8 +8,8 @@
 
 #pragma once
 
+#include <adwaita.h>
 #include <gtk/gtk.h>
-#include <handy.h>
 
 #include "gnome-software-private.h"
 
@@ -17,7 +17,7 @@ G_BEGIN_DECLS
 
 #define GS_TYPE_PREFS_DIALOG (gs_prefs_dialog_get_type ())
 
-G_DECLARE_FINAL_TYPE (GsPrefsDialog, gs_prefs_dialog, GS, PREFS_DIALOG, HdyPreferencesWindow)
+G_DECLARE_FINAL_TYPE (GsPrefsDialog, gs_prefs_dialog, GS, PREFS_DIALOG, AdwPreferencesWindow)
 
 GtkWidget      *gs_prefs_dialog_new            (GtkWindow      *parent,
                                                 GsPluginLoader *plugin_loader);
diff --git a/src/gs-prefs-dialog.ui b/src/gs-prefs-dialog.ui
index 2ccde058f..0a19a0c72 100644
--- a/src/gs-prefs-dialog.ui
+++ b/src/gs-prefs-dialog.ui
@@ -1,7 +1,7 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <interface>
   <requires lib="gtk+" version="3.10"/>
-  <template class="GsPrefsDialog" parent="HdyPreferencesWindow">
+  <template class="GsPrefsDialog" parent="AdwPreferencesWindow">
     <property name="title" translatable="yes">Update Preferences</property>
     <property name="default_width">610</property>
     <property name="default_height">300</property>
@@ -10,14 +10,14 @@
       <class name="update-preferences"/>
     </style>
     <child>
-      <object class="HdyPreferencesPage">
+      <object class="AdwPreferencesPage">
         <property name="visible">True</property>
         <child>
-          <object class="HdyPreferencesGroup">
+          <object class="AdwPreferencesGroup">
             <property name="visible">True</property>
             <property name="description" translatable="yes">To avoid charges and network caps, software 
updates are not automatically downloaded on mobile or metered connections.</property>
             <child>
-              <object class="HdyActionRow">
+              <object class="AdwActionRow">
                 <property name="visible">True</property>
                 <property name="title" translatable="yes">Automatic Updates</property>
                 <property name="subtitle" translatable="yes">Downloads and installs software updates in the 
background, when possible.</property>
@@ -32,7 +32,7 @@
               </object>
             </child>
             <child>
-              <object class="HdyActionRow">
+              <object class="AdwActionRow">
                 <property name="visible">True</property>
                 <property name="title" translatable="yes">Automatic Update Notifications</property>
                 <property name="subtitle" translatable="yes">Show notifications when updates have been 
automatically installed.</property>
diff --git a/src/gs-repos-dialog.h b/src/gs-repos-dialog.h
index 1349830e8..c7b4e7530 100644
--- a/src/gs-repos-dialog.h
+++ b/src/gs-repos-dialog.h
@@ -9,8 +9,8 @@
 
 #pragma once
 
+#include <adwaita.h>
 #include <gtk/gtk.h>
-#include <handy.h>
 
 #include "gnome-software-private.h"
 
@@ -18,7 +18,7 @@ G_BEGIN_DECLS
 
 #define GS_TYPE_REPOS_DIALOG (gs_repos_dialog_get_type ())
 
-G_DECLARE_FINAL_TYPE (GsReposDialog, gs_repos_dialog, GS, REPOS_DIALOG, HdyWindow)
+G_DECLARE_FINAL_TYPE (GsReposDialog, gs_repos_dialog, GS, REPOS_DIALOG, AdwWindow)
 
 GtkWidget      *gs_repos_dialog_new            (GtkWindow      *parent,
                                                 GsPluginLoader *plugin_loader);
diff --git a/src/gs-repos-dialog.ui b/src/gs-repos-dialog.ui
index 078a5c0ce..5e28f4e24 100644
--- a/src/gs-repos-dialog.ui
+++ b/src/gs-repos-dialog.ui
@@ -1,7 +1,7 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <interface>
   <requires lib="gtk+" version="3.10"/>
-  <template class="GsReposDialog" parent="HdyWindow">
+  <template class="GsReposDialog" parent="AdwWindow">
     <property name="modal">True</property>
     <property name="window_position">center</property>
     <property name="destroy_with_parent">True</property>
@@ -19,7 +19,7 @@
         <property name="orientation">vertical</property>
         <property name="width-request">360</property>
         <child>
-          <object class="HdyHeaderBar">
+          <object class="AdwHeaderBar">
             <property name="show_close_button">True</property>
             <property name="visible">True</property>
             <property name="title" bind-source="GsReposDialog" bind-property="title" 
bind-flags="sync-create"/>
@@ -44,7 +44,7 @@
               </packing>
             </child>
             <child>
-              <object class="HdyStatusPage" id="status_empty">
+              <object class="AdwStatusPage" id="status_empty">
                 <property name="visible">True</property>
                 <property name="icon_name">org.gnome.Software-symbolic</property>
                 <property name="title" translatable="yes">No Repositories</property>
@@ -54,7 +54,7 @@
               </packing>
             </child>
             <child>
-              <object class="HdyPreferencesPage" id="content_page">
+              <object class="AdwPreferencesPage" id="content_page">
                 <property name="visible">True</property>
               </object>
               <packing>
diff --git a/src/gs-repos-section.c b/src/gs-repos-section.c
index a9b08200f..9577d7287 100644
--- a/src/gs-repos-section.c
+++ b/src/gs-repos-section.c
@@ -15,7 +15,7 @@
 
 struct _GsReposSection
 {
-       HdyPreferencesGroup      parent_instance;
+       AdwPreferencesGroup      parent_instance;
        GtkWidget               *title;
        GtkListBox              *list;
        GsPluginLoader          *plugin_loader;
@@ -23,7 +23,7 @@ struct _GsReposSection
        gboolean                 always_allow_enable_disable;
 };
 
-G_DEFINE_TYPE (GsReposSection, gs_repos_section, HDY_TYPE_PREFERENCES_GROUP)
+G_DEFINE_TYPE (GsReposSection, gs_repos_section, ADW_TYPE_PREFERENCES_GROUP)
 
 enum {
        SIGNAL_REMOVE_CLICKED,
diff --git a/src/gs-repos-section.h b/src/gs-repos-section.h
index 9a58a3e1a..9f373f94c 100644
--- a/src/gs-repos-section.h
+++ b/src/gs-repos-section.h
@@ -8,8 +8,8 @@
 
 #pragma once
 
+#include <adwaita.h>
 #include <gtk/gtk.h>
-#include <handy.h>
 
 #include "gnome-software-private.h"
 #include "gs-app.h"
@@ -18,7 +18,7 @@ G_BEGIN_DECLS
 
 #define GS_TYPE_REPOS_SECTION (gs_repos_section_get_type ())
 
-G_DECLARE_FINAL_TYPE (GsReposSection, gs_repos_section, GS, REPOS_SECTION, HdyPreferencesGroup)
+G_DECLARE_FINAL_TYPE (GsReposSection, gs_repos_section, GS, REPOS_SECTION, AdwPreferencesGroup)
 
 GtkWidget      *gs_repos_section_new                   (GsPluginLoader         *plugin_loader,
                                                         gboolean                always_allow_enable_disable);
diff --git a/src/gs-rounded-bin.c b/src/gs-rounded-bin.c
index 5e02785fb..8c077c933 100644
--- a/src/gs-rounded-bin.c
+++ b/src/gs-rounded-bin.c
@@ -28,7 +28,7 @@
  * ]|
  *
  * Adapted from
- *  * https://gitlab.gnome.org/GNOME/libhandy/-/blob/1.0.0/src/hdy-window-mixin.c
+ *  * https://gitlab.gnome.org/GNOME/libhandy/-/blob/1.0.0/src/adw-window-mixin.c
  *  * https://gitlab.gnome.org/GNOME/fractal/-/blob/c69aacc4/fractal-gtk/src/widgets/clip_container.rs
  *
  * Since: 40
diff --git a/src/gs-safety-context-dialog.c b/src/gs-safety-context-dialog.c
index 3136bd206..a93128ff4 100644
--- a/src/gs-safety-context-dialog.c
+++ b/src/gs-safety-context-dialog.c
@@ -28,11 +28,11 @@
 
 #include "config.h"
 
+#include <adwaita.h>
 #include <glib.h>
 #include <glib-object.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <handy.h>
 #include <locale.h>
 
 #include "gs-app.h"
diff --git a/src/gs-safety-context-dialog.ui b/src/gs-safety-context-dialog.ui
index 3ae35f797..16fccf4fb 100644
--- a/src/gs-safety-context-dialog.ui
+++ b/src/gs-safety-context-dialog.ui
@@ -4,10 +4,10 @@
   <template class="GsSafetyContextDialog" parent="GsInfoWindow">
     <property name="title" translatable="yes" comments="Translators: This is the title of the dialog which 
contains information about the permissions of an app">Safety</property>
     <child>
-      <object class="HdyPreferencesPage">
+      <object class="AdwPreferencesPage">
         <property name="visible">True</property>
         <child>
-          <object class="HdyPreferencesGroup">
+          <object class="AdwPreferencesGroup">
             <property name="visible">True</property>
 
             <child>
@@ -89,7 +89,7 @@
                 </child>
 
                 <child>
-                  <object class="HdyPreferencesGroup">
+                  <object class="AdwPreferencesGroup">
                     <property name="margin-top">20</property>
                     <property name="title" translatable="yes">Details</property>
                     <property name="visible">True</property>
diff --git a/src/gs-screenshot-carousel.c b/src/gs-screenshot-carousel.c
index a06037e2d..9c08c423a 100644
--- a/src/gs-screenshot-carousel.c
+++ b/src/gs-screenshot-carousel.c
@@ -26,8 +26,8 @@
 
 #include "config.h"
 
+#include <adwaita.h>
 #include <glib/gi18n.h>
-#include <handy.h>
 #include <locale.h>
 #include <math.h>
 #include <string.h>
@@ -178,7 +178,7 @@ gs_screenshot_carousel_get_has_screenshots (GsScreenshotCarousel *self)
 }
 
 static void
-_carousel_navigate (HdyCarousel *carousel, HdyNavigationDirection direction)
+_carousel_navigate (AdwCarousel *carousel, AdwNavigationDirection direction)
 {
        g_autoptr (GList) children = NULL;
        GtkWidget *child;
@@ -188,8 +188,8 @@ _carousel_navigate (HdyCarousel *carousel, HdyNavigationDirection direction)
        children = gtk_container_get_children (GTK_CONTAINER (carousel));
        n_children = g_list_length (children);
 
-       position = hdy_carousel_get_position (carousel);
-       position += (direction == HDY_NAVIGATION_DIRECTION_BACK) ? -1 : 1;
+       position = adw_carousel_get_position (carousel);
+       position += (direction == ADW_NAVIGATION_DIRECTION_BACK) ? -1 : 1;
        /* Round the position to the closest integer in the valid range. */
        position = round (position);
        position = MIN (position, n_children - 1);
@@ -197,14 +197,14 @@ _carousel_navigate (HdyCarousel *carousel, HdyNavigationDirection direction)
 
        child = g_list_nth_data (children, position);
        if (child)
-               hdy_carousel_scroll_to (carousel, child);
+               adw_carousel_scroll_to (carousel, child);
 }
 
 static void
 gs_screenshot_carousel_update_buttons (GsScreenshotCarousel *self)
 {
-       gdouble position = hdy_carousel_get_position (HDY_CAROUSEL (self->carousel));
-       guint n_pages = hdy_carousel_get_n_pages (HDY_CAROUSEL (self->carousel));
+       gdouble position = adw_carousel_get_position (ADW_CAROUSEL (self->carousel));
+       guint n_pages = adw_carousel_get_n_pages (ADW_CAROUSEL (self->carousel));
        gtk_revealer_set_reveal_child (GTK_REVEALER (self->button_previous_revealer), position >= 0.5);
        gtk_revealer_set_reveal_child (GTK_REVEALER (self->button_next_revealer), position < n_pages - 1.5);
 }
@@ -224,15 +224,15 @@ gs_screenshot_carousel_notify_position_cb (GsScreenshotCarousel *self)
 static void
 gs_screenshot_carousel_button_previous_clicked_cb (GsScreenshotCarousel *self)
 {
-       _carousel_navigate (HDY_CAROUSEL (self->carousel),
-                           HDY_NAVIGATION_DIRECTION_BACK);
+       _carousel_navigate (ADW_CAROUSEL (self->carousel),
+                           ADW_NAVIGATION_DIRECTION_BACK);
 }
 
 static void
 gs_screenshot_carousel_button_next_clicked_cb (GsScreenshotCarousel *self)
 {
-       _carousel_navigate (HDY_CAROUSEL (self->carousel),
-                           HDY_NAVIGATION_DIRECTION_FORWARD);
+       _carousel_navigate (ADW_CAROUSEL (self->carousel),
+                           ADW_NAVIGATION_DIRECTION_FORWARD);
 }
 
 static void
@@ -349,10 +349,10 @@ gs_screenshot_carousel_init (GsScreenshotCarousel *self)
        gs_screenshot_carousel_navigate_button_direction_changed_cb (GTK_WIDGET (self->button_next_image), 
GTK_TEXT_DIR_NONE, self);
        gs_screenshot_carousel_navigate_button_direction_changed_cb (GTK_WIDGET 
(self->button_previous_image), GTK_TEXT_DIR_NONE, self);
 
-#if HDY_CHECK_VERSION(1, 3, 0)
+#if ADW_CHECK_VERSION(1, 3, 0)
        /* Disable scrolling through the carousel, as it’s typically used
         * in application pages which are themselves scrollable. */
-       hdy_carousel_set_allow_scroll_wheel (HDY_CAROUSEL (self->carousel), FALSE);
+       adw_carousel_set_allow_scroll_wheel (ADW_CAROUSEL (self->carousel), FALSE);
 #endif
 
        /* setup networking */
diff --git a/src/gs-screenshot-carousel.ui b/src/gs-screenshot-carousel.ui
index 2c9ec6f1d..2b3d2994d 100644
--- a/src/gs-screenshot-carousel.ui
+++ b/src/gs-screenshot-carousel.ui
@@ -16,7 +16,7 @@
           <object class="GtkOverlay">
             <property name="visible">True</property>
             <child>
-              <object class="HdyCarousel" id="carousel">
+              <object class="AdwCarousel" id="carousel">
                 <property name="visible">True</property>
                 <signal name="notify::n-pages" handler="gs_screenshot_carousel_notify_n_pages_cb" 
swapped="yes"/>
                 <signal name="notify::position" handler="gs_screenshot_carousel_notify_position_cb" 
swapped="yes"/>
@@ -107,7 +107,7 @@
           </object>
         </child>
         <child>
-          <object class="HdyCarouselIndicatorDots" id="carousel_indicator">
+          <object class="AdwCarouselIndicatorDots" id="carousel_indicator">
             <property name="carousel">carousel</property>
             <property name="visible">True</property>
           </object>
diff --git a/src/gs-search-page.ui b/src/gs-search-page.ui
index 3fbeebe37..9e5696389 100644
--- a/src/gs-search-page.ui
+++ b/src/gs-search-page.ui
@@ -11,7 +11,7 @@
       <object class="GtkStack" id="stack_search">
         <property name="visible">True</property>
         <child>
-          <object class="HdyStatusPage">
+          <object class="AdwStatusPage">
             <property name="visible">True</property>
             <property name="icon_name">org.gnome.Software-symbolic</property>
             <property name="title" translatable="yes">Search for Apps</property>
@@ -33,7 +33,7 @@
           </packing>
         </child>
         <child>
-          <object class="HdyStatusPage" id="noresults_grid_search">
+          <object class="AdwStatusPage" id="noresults_grid_search">
             <property name="visible">True</property>
             <property name="icon_name">org.gnome.Software-symbolic</property>
             <property name="title" translatable="yes">No Application Found</property>
@@ -53,7 +53,7 @@
               <class name="list-page"/>
             </style>
             <child>
-              <object class="HdyClamp">
+              <object class="AdwClamp">
                 <property name="visible">True</property>
                 <property name="maximum-size">860</property>
                 <!-- ~⅔ of the maximum size. -->
diff --git a/src/gs-shell.c b/src/gs-shell.c
index 18c9e98f4..cb6aaea44 100644
--- a/src/gs-shell.c
+++ b/src/gs-shell.c
@@ -10,7 +10,7 @@
 
 #include "config.h"
 
-#include <handy.h>
+#include <adwaita.h>
 #include <string.h>
 #include <glib/gi18n.h>
 
@@ -61,7 +61,7 @@ typedef struct {
 
 struct _GsShell
 {
-       HdyApplicationWindow     parent_object;
+       AdwApplicationWindow     parent_object;
 
        GSettings               *settings;
        GCancellable            *cancellable;
@@ -72,8 +72,8 @@ struct _GsShell
        GQueue                  *back_entry_stack;
        GPtrArray               *modal_dialogs;
        gchar                   *events_info_uri;
-       HdyDeck                 *main_deck;
-       HdyDeck                 *details_deck;
+       AdwDeck                 *main_deck;
+       AdwDeck                 *details_deck;
        GtkStack                *stack_loading;
        GtkStack                *stack_main;
        GtkStack                *stack_sub;
@@ -112,7 +112,7 @@ struct _GsShell
        GsPage                  *pages[GS_SHELL_MODE_LAST];
 };
 
-G_DEFINE_TYPE (GsShell, gs_shell, HDY_TYPE_APPLICATION_WINDOW)
+G_DEFINE_TYPE (GsShell, gs_shell, ADW_TYPE_APPLICATION_WINDOW)
 
 typedef enum {
        PROP_IS_NARROW = 1,
@@ -179,7 +179,7 @@ gs_shell_set_header_start_widget (GsShell *shell, GtkWidget *widget)
 
        if (widget != NULL) {
                g_object_ref (widget);
-               hdy_header_bar_pack_start (HDY_HEADER_BAR (shell->main_header), widget);
+               adw_header_bar_pack_start (ADW_HEADER_BAR (shell->main_header), widget);
        }
 
        shell->header_start_widget = widget;
@@ -202,7 +202,7 @@ gs_shell_set_header_end_widget (GsShell *shell, GtkWidget *widget)
 
        if (widget != NULL) {
                g_object_ref (widget);
-               hdy_header_bar_pack_end (HDY_HEADER_BAR (shell->main_header), widget);
+               adw_header_bar_pack_end (ADW_HEADER_BAR (shell->main_header), widget);
        }
 
        shell->header_end_widget = widget;
@@ -225,7 +225,7 @@ gs_shell_set_details_header_end_widget (GsShell *shell, GtkWidget *widget)
 
        if (widget != NULL) {
                g_object_ref (widget);
-               hdy_header_bar_pack_end (HDY_HEADER_BAR (shell->details_header), widget);
+               adw_header_bar_pack_end (ADW_HEADER_BAR (shell->details_header), widget);
        }
 
        shell->details_header_end_widget = widget;
@@ -468,7 +468,7 @@ update_header_widgets (GsShell *shell)
        g_signal_handlers_block_by_func (shell->search_button, search_button_clicked_cb, shell);
 
        /* hide unless we're going to search */
-       hdy_search_bar_set_search_mode (HDY_SEARCH_BAR (shell->search_bar),
+       adw_search_bar_set_search_mode (ADW_SEARCH_BAR (shell->search_bar),
                                        mode == GS_SHELL_MODE_SEARCH);
 
        g_signal_handlers_unblock_by_func (shell->search_button, search_button_clicked_cb, shell);
@@ -597,15 +597,15 @@ gs_shell_change_mode (GsShell *shell,
 
        gtk_stack_set_visible_child_name (shell->stack_loading, "main");
        if (mode == GS_SHELL_MODE_DETAILS) {
-               hdy_deck_set_visible_child_name (shell->details_deck, "details");
+               adw_deck_set_visible_child_name (shell->details_deck, "details");
        } else {
-               hdy_deck_set_visible_child_name (shell->details_deck, "main");
+               adw_deck_set_visible_child_name (shell->details_deck, "main");
                /* We only change the main deck when not reaching the details
                 * page to preserve the navigation history in the UI's state.
                 * First change the page, then the deck, to avoid load of
                 * the previously shown page, which will be changed shortly after. */
                gtk_stack_set_visible_child_name (mode_is_main ? shell->stack_main : shell->stack_sub, 
page_name[mode]);
-               hdy_deck_set_visible_child_name (shell->main_deck, mode_is_main ? "main" : "sub");
+               adw_deck_set_visible_child_name (shell->main_deck, mode_is_main ? "main" : "sub");
        }
 
        /* do any mode-specific actions */
@@ -648,7 +648,7 @@ overlay_get_child_position_cb (GtkOverlay   *overlay,
         * to position it below the header bar. The overlay can’t easily be
         * moved in the widget hierarchy so it doesn’t have the header bar as
         * a child, since there are several header bars in different pages of
-        * a HdyDeck. */
+        * a AdwDeck. */
        g_assert (gtk_widget_is_ancestor (self->main_header, GTK_WIDGET (overlay)));
 
        gtk_widget_get_preferred_size (widget, NULL, &overlay_natural_size);
@@ -912,10 +912,10 @@ window_keypress_handler (GtkWidget *window, GdkEvent *event, GsShell *shell)
                GdkEventKey *e = (GdkEventKey *) event;
                if ((e->state & GDK_CONTROL_MASK) > 0 &&
                    e->keyval == GDK_KEY_f) {
-                       if (!hdy_search_bar_get_search_mode (HDY_SEARCH_BAR (shell->search_bar))) {
+                       if (!adw_search_bar_get_search_mode (ADW_SEARCH_BAR (shell->search_bar))) {
                                GsShellMode mode = gs_shell_get_mode (shell);
 
-                               hdy_search_bar_set_search_mode (HDY_SEARCH_BAR (shell->search_bar), TRUE);
+                               adw_search_bar_set_search_mode (ADW_SEARCH_BAR (shell->search_bar), TRUE);
                                gtk_widget_grab_focus (shell->entry_search);
 
                                /* If the mode doesn't have a search button,
@@ -932,14 +932,14 @@ window_keypress_handler (GtkWidget *window, GdkEvent *event, GsShell *shell)
                                        break;
                                }
                        } else {
-                               hdy_search_bar_set_search_mode (HDY_SEARCH_BAR (shell->search_bar), FALSE);
+                               adw_search_bar_set_search_mode (ADW_SEARCH_BAR (shell->search_bar), FALSE);
                        }
                        return GDK_EVENT_STOP;
                }
        }
 
        /* pass to search bar */
-       return hdy_search_bar_handle_event (HDY_SEARCH_BAR (shell->search_bar), event);
+       return adw_search_bar_handle_event (ADW_SEARCH_BAR (shell->search_bar), event);
 }
 
 static void
@@ -2269,10 +2269,10 @@ gs_shell_get_mode (GsShell *shell)
        if (g_strcmp0 (gtk_stack_get_visible_child_name (shell->stack_loading), "loading") == 0)
                return GS_SHELL_MODE_LOADING;
 
-       if (g_strcmp0 (hdy_deck_get_visible_child_name (shell->details_deck), "details") == 0)
+       if (g_strcmp0 (adw_deck_get_visible_child_name (shell->details_deck), "details") == 0)
                return GS_SHELL_MODE_DETAILS;
 
-       if (g_strcmp0 (hdy_deck_get_visible_child_name (shell->main_deck), "main") == 0)
+       if (g_strcmp0 (adw_deck_get_visible_child_name (shell->main_deck), "main") == 0)
                name = gtk_stack_get_visible_child_name (shell->stack_main);
        else
                name = gtk_stack_get_visible_child_name (shell->stack_sub);
@@ -2627,7 +2627,7 @@ gs_shell_init (GsShell *shell)
 {
        gtk_widget_init_template (GTK_WIDGET (shell));
 
-       hdy_search_bar_connect_entry (HDY_SEARCH_BAR (shell->search_bar), GTK_ENTRY (shell->entry_search));
+       adw_search_bar_connect_entry (ADW_SEARCH_BAR (shell->search_bar), GTK_ENTRY (shell->entry_search));
 
        shell->back_entry_stack = g_queue_new ();
        shell->modal_dialogs = g_ptr_array_new_with_free_func ((GDestroyNotify) gtk_widget_destroy);
diff --git a/src/gs-shell.h b/src/gs-shell.h
index bb39fc928..d11345b46 100644
--- a/src/gs-shell.h
+++ b/src/gs-shell.h
@@ -9,8 +9,8 @@
 
 #pragma once
 
+#include <adwaita.h>
 #include <gtk/gtk.h>
-#include <handy.h>
 
 #include "gnome-software-private.h"
 
@@ -18,7 +18,7 @@ G_BEGIN_DECLS
 
 #define GS_TYPE_SHELL (gs_shell_get_type ())
 
-G_DECLARE_FINAL_TYPE (GsShell, gs_shell, GS, SHELL, HdyApplicationWindow)
+G_DECLARE_FINAL_TYPE (GsShell, gs_shell, GS, SHELL, AdwApplicationWindow)
 
 typedef enum {
        GS_SHELL_MODE_UNKNOWN,
diff --git a/src/gs-shell.ui b/src/gs-shell.ui
index b627c2b11..55955fb9e 100644
--- a/src/gs-shell.ui
+++ b/src/gs-shell.ui
@@ -14,7 +14,7 @@
     </item>
   </menu>
 
-  <template class="GsShell" parent="HdyApplicationWindow">
+  <template class="GsShell" parent="AdwApplicationWindow">
     <property name="visible">False</property>
     <property name="default-width">1200</property>
     <property name="default-height">800</property>
@@ -139,11 +139,11 @@
               </object>
             </child>
             <child>
-              <object class="HdyDeck" id="details_deck">
+              <object class="AdwDeck" id="details_deck">
                 <property name="visible">True</property>
                 <signal name="notify::visible-child" handler="stack_notify_visible_child_cb"/>
                 <child>
-                  <object class="HdyDeck" id="main_deck">
+                  <object class="AdwDeck" id="main_deck">
                     <property name="visible">True</property>
                     <signal name="notify::visible-child" handler="stack_notify_visible_child_cb"/>
                     <child>
@@ -151,7 +151,7 @@
                         <property name="visible">True</property>
                         <property name="orientation">vertical</property>
                         <child>
-                          <object class="HdyHeaderBar" id="main_header">
+                          <object class="AdwHeaderBar" id="main_header">
                             <property name="visible">True</property>
                             <property name="can-focus">False</property>
                             <property name="hexpand">True</property>
@@ -210,7 +210,7 @@
                               </packing>
                             </child>
                             <child type="title">
-                              <object class="HdyViewSwitcherTitle" id="title_switcher">
+                              <object class="AdwViewSwitcherTitle" id="title_switcher">
                                 <property name="visible">True</property>
                                 <property name="stack">stack_main</property>
                                 <property name="title" bind-source="GsShell" bind-property="title" 
bind-flags="sync-create"/>
@@ -219,10 +219,10 @@
                           </object>
                         </child>
                         <child>
-                          <object class="HdySearchBar" id="search_bar">
+                          <object class="AdwSearchBar" id="search_bar">
                             <property name="visible">True</property>
                             <child>
-                              <object class="HdyClamp">
+                              <object class="AdwClamp">
                                 <property name="visible">True</property>
                                 <property name="hexpand">True</property>
                                 <property name="maximum_size">500</property>
@@ -343,7 +343,7 @@
                           </object>
                         </child>
                         <child>
-                          <object class="HdyViewSwitcherBar" id="sidebar_switcher">
+                          <object class="AdwViewSwitcherBar" id="sidebar_switcher">
                             <property name="visible">True</property>
                             <property name="reveal" bind-source="title_switcher" 
bind-property="title-visible" bind-flags="sync-create"/>
                             <property name="stack">stack_main</property>
@@ -359,7 +359,7 @@
                         <property name="visible">True</property>
                         <property name="orientation">vertical</property>
                         <child>
-                          <object class="HdyHeaderBar" id="sub_header">
+                          <object class="AdwHeaderBar" id="sub_header">
                             <property name="visible">True</property>
                             <property name="can-focus">False</property>
                             <property name="hexpand">True</property>
@@ -446,7 +446,7 @@
                     <property name="visible">True</property>
                     <property name="orientation">vertical</property>
                     <child>
-                      <object class="HdyHeaderBar" id="details_header">
+                      <object class="AdwHeaderBar" id="details_header">
                         <property name="visible">True</property>
                         <property name="can-focus">False</property>
                         <property name="hexpand">True</property>
@@ -505,7 +505,7 @@
               </object>
             </child>
             <child>
-              <object class="HdyWindowHandle">
+              <object class="AdwWindowHandle">
                 <property name="visible">True</property>
                 <child>
                   <object class="GsLoadingPage" id="loading_page">
diff --git a/src/gs-storage-context-dialog.c b/src/gs-storage-context-dialog.c
index 5c3f2911f..f270ba67c 100644
--- a/src/gs-storage-context-dialog.c
+++ b/src/gs-storage-context-dialog.c
@@ -28,11 +28,11 @@
 
 #include "config.h"
 
+#include <adwaita.h>
 #include <glib.h>
 #include <glib-object.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <handy.h>
 #include <locale.h>
 
 #include "gs-app.h"
diff --git a/src/gs-storage-context-dialog.ui b/src/gs-storage-context-dialog.ui
index 794f1e916..465f30f31 100644
--- a/src/gs-storage-context-dialog.ui
+++ b/src/gs-storage-context-dialog.ui
@@ -4,10 +4,10 @@
   <template class="GsStorageContextDialog" parent="GsInfoWindow">
     <property name="title" translatable="yes" comments="Translators: This is the title of the dialog which 
contains information about the storage or download size needed for an app">Storage</property>
     <child>
-      <object class="HdyPreferencesPage">
+      <object class="AdwPreferencesPage">
         <property name="visible">True</property>
         <child>
-          <object class="HdyPreferencesGroup">
+          <object class="AdwPreferencesGroup">
             <property name="visible">True</property>
 
             <child>
diff --git a/src/gs-update-dialog.c b/src/gs-update-dialog.c
index c73d61d1d..0c423495a 100644
--- a/src/gs-update-dialog.c
+++ b/src/gs-update-dialog.c
@@ -20,7 +20,7 @@
 
 struct _GsUpdateDialog
 {
-       HdyWindow        parent_instance;
+       AdwWindow        parent_instance;
 
        GCancellable    *cancellable;
        GsPluginLoader  *plugin_loader;
@@ -31,7 +31,7 @@ struct _GsUpdateDialog
        GtkWidget       *stack;
 };
 
-G_DEFINE_TYPE (GsUpdateDialog, gs_update_dialog, HDY_TYPE_WINDOW)
+G_DEFINE_TYPE (GsUpdateDialog, gs_update_dialog, ADW_TYPE_WINDOW)
 
 typedef enum {
        PROP_PLUGIN_LOADER = 1,
@@ -44,14 +44,14 @@ static void gs_update_dialog_show_installed_updates (GsUpdateDialog *dialog);
 static void gs_update_dialog_show_update_details (GsUpdateDialog *dialog, GsApp *app);
 
 static void
-deck_child_transition_cb (HdyDeck *deck, GParamSpec *pspec, GsUpdateDialog *dialog)
+deck_child_transition_cb (AdwDeck *deck, GParamSpec *pspec, GsUpdateDialog *dialog)
 {
        GtkWidget *child;
 
-       if (hdy_deck_get_transition_running (deck))
+       if (adw_deck_get_transition_running (deck))
                return;
 
-       while ((child = hdy_deck_get_adjacent_child (deck, HDY_NAVIGATION_DIRECTION_FORWARD)))
+       while ((child = adw_deck_get_adjacent_child (deck, ADW_NAVIGATION_DIRECTION_FORWARD)))
                gtk_widget_destroy (child);
 }
 
@@ -169,7 +169,7 @@ unset_focus (GtkWidget *widget)
 static void
 back_clicked_cb (GtkWidget *widget, GsUpdateDialog *dialog)
 {
-       hdy_deck_navigate (HDY_DECK (dialog->deck), HDY_NAVIGATION_DIRECTION_BACK);
+       adw_deck_navigate (ADW_DECK (dialog->deck), ADW_NAVIGATION_DIRECTION_BACK);
 }
 
 static void
@@ -211,7 +211,7 @@ gs_update_dialog_show_update_details (GsUpdateDialog *dialog, GsApp *app)
        gtk_widget_show (page);
 
        gtk_container_add (GTK_CONTAINER (dialog->deck), page);
-       hdy_deck_set_visible_child (HDY_DECK (dialog->deck), page);
+       adw_deck_set_visible_child (ADW_DECK (dialog->deck), page);
 }
 
 static gboolean
@@ -237,7 +237,7 @@ key_press_event (GtkWidget *widget, GdkEventKey *event, gpointer user_data)
        if ((!is_rtl && state == GDK_MOD1_MASK && event->keyval == GDK_KEY_Left) ||
            (is_rtl && state == GDK_MOD1_MASK && event->keyval == GDK_KEY_Right) ||
            event->keyval == GDK_KEY_Back) {
-               hdy_deck_navigate (HDY_DECK (dialog->deck), HDY_NAVIGATION_DIRECTION_BACK);
+               adw_deck_navigate (ADW_DECK (dialog->deck), ADW_NAVIGATION_DIRECTION_BACK);
                return GDK_EVENT_STOP;
        }
 
@@ -251,7 +251,7 @@ button_press_event (GsUpdateDialog *dialog, GdkEventButton *event)
        if (event->button != 8)
                return GDK_EVENT_PROPAGATE;
 
-       hdy_deck_navigate (HDY_DECK (dialog->deck), HDY_NAVIGATION_DIRECTION_BACK);
+       adw_deck_navigate (ADW_DECK (dialog->deck), ADW_NAVIGATION_DIRECTION_BACK);
        return GDK_EVENT_STOP;
 }
 
@@ -307,12 +307,12 @@ gs_update_dialog_constructed (GObject *object)
        if (dialog->app) {
                GtkWidget *child;
 
-               child = hdy_deck_get_visible_child (HDY_DECK (dialog->deck));
+               child = adw_deck_get_visible_child (ADW_DECK (dialog->deck));
                gtk_container_remove (GTK_CONTAINER (dialog->deck), child);
 
                gs_update_dialog_show_update_details (dialog, dialog->app);
 
-               child = hdy_deck_get_visible_child (HDY_DECK (dialog->deck));
+               child = adw_deck_get_visible_child (ADW_DECK (dialog->deck));
                /* It can be either the app details page or the OS update page */
                if (GS_IS_APP_DETAILS_PAGE (child))
                        gs_app_details_page_set_show_back_button (GS_APP_DETAILS_PAGE (child), FALSE);
diff --git a/src/gs-update-dialog.h b/src/gs-update-dialog.h
index 14b1d4e41..5e177eb83 100644
--- a/src/gs-update-dialog.h
+++ b/src/gs-update-dialog.h
@@ -9,8 +9,8 @@
 
 #pragma once
 
+#include <adwaita.h>
 #include <gtk/gtk.h>
-#include <handy.h>
 
 #include "gnome-software-private.h"
 
@@ -18,7 +18,7 @@ G_BEGIN_DECLS
 
 #define GS_TYPE_UPDATE_DIALOG (gs_update_dialog_get_type ())
 
-G_DECLARE_FINAL_TYPE (GsUpdateDialog, gs_update_dialog, GS, UPDATE_DIALOG, HdyWindow)
+G_DECLARE_FINAL_TYPE (GsUpdateDialog, gs_update_dialog, GS, UPDATE_DIALOG, AdwWindow)
 
 GtkWidget      *gs_update_dialog_new                           (GsPluginLoader         *plugin_loader);
 GtkWidget      *gs_update_dialog_new_for_app                   (GsPluginLoader         *plugin_loader,
diff --git a/src/gs-update-dialog.ui b/src/gs-update-dialog.ui
index 9a2705afa..995cb507d 100644
--- a/src/gs-update-dialog.ui
+++ b/src/gs-update-dialog.ui
@@ -1,7 +1,7 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <interface>
   <requires lib="gtk+" version="3.10"/>
-  <template class="GsUpdateDialog" parent="HdyWindow">
+  <template class="GsUpdateDialog" parent="AdwWindow">
     <property name="modal">True</property>
     <property name="window_position">center</property>
     <property name="destroy_with_parent">True</property>
@@ -13,7 +13,7 @@
     <property name="default-height">576</property>
 
     <child>
-      <object class="HdyDeck" id="deck">
+      <object class="AdwDeck" id="deck">
         <property name="visible">True</property>
         <property name="can_swipe_back">True</property>
         <!-- We need both signals to support the animations being disabled, as
@@ -25,7 +25,7 @@
             <property name="visible">True</property>
             <property name="orientation">vertical</property>
             <child>
-              <object class="HdyHeaderBar">
+              <object class="AdwHeaderBar">
                 <property name="show_close_button">True</property>
                 <property name="visible">True</property>
                 <property name="title" bind-source="GsUpdateDialog" bind-property="title" 
bind-flags="sync-create"/>
@@ -64,7 +64,7 @@
                   </packing>
                 </child>
                 <child>
-                  <object class="HdyStatusPage">
+                  <object class="AdwStatusPage">
                     <property name="visible">True</property>
                     <property name="icon_name">org.gnome.Software-symbolic</property>
                     <property name="title" translatable="yes">No updates have been installed on this 
system.</property>
@@ -74,10 +74,10 @@
                   </packing>
                 </child>
                 <child>
-                  <object class="HdyPreferencesPage">
+                  <object class="AdwPreferencesPage">
                     <property name="visible">True</property>
                     <child>
-                      <object class="HdyPreferencesGroup">
+                      <object class="AdwPreferencesGroup">
                         <property name="visible">True</property>
                         <child>
                           <object class="GsUpdateList" id="list_box_installed_updates">
diff --git a/src/gs-updates-page.c b/src/gs-updates-page.c
index 7b75c07e3..4e9febec9 100644
--- a/src/gs-updates-page.c
+++ b/src/gs-updates-page.c
@@ -453,7 +453,7 @@ gs_updates_page_get_updates_cb (GsPluginLoader *plugin_loader,
                gs_updates_page_clear_flag (self, GS_UPDATES_PAGE_FLAG_HAS_UPDATES);
                if (!g_error_matches (error, GS_PLUGIN_ERROR, GS_PLUGIN_ERROR_CANCELLED))
                        g_warning ("updates-shell: failed to get updates: %s", error->message);
-               hdy_status_page_set_description (HDY_STATUS_PAGE (self->updates_failed_page),
+               adw_status_page_set_description (ADW_STATUS_PAGE (self->updates_failed_page),
                                                 error->message);
                gs_updates_page_set_state (self, GS_UPDATES_PAGE_STATE_FAILED);
                refresh_headerbar_updates_counter (self);
@@ -751,7 +751,7 @@ gs_updates_page_refresh_cb (GsPluginLoader *plugin_loader,
                        return;
                }
                g_warning ("failed to refresh: %s", error->message);
-               hdy_status_page_set_description (HDY_STATUS_PAGE (self->updates_failed_page),
+               adw_status_page_set_description (ADW_STATUS_PAGE (self->updates_failed_page),
                                                 error->message);
                gs_updates_page_set_state (self, GS_UPDATES_PAGE_STATE_FAILED);
                return;
@@ -1283,9 +1283,9 @@ gs_updates_page_setup (GsPage *page,
        gs_page_set_header_start_widget (GS_PAGE (self), self->header_start_box);
 
        /* This label indicates that the update check is in progress */
-       self->header_checking_label = hdy_squeezer_new ();
-       hdy_squeezer_set_xalign (HDY_SQUEEZER (self->header_checking_label), 0);
-       hdy_squeezer_set_transition_type (HDY_SQUEEZER (self->header_checking_label), 
HDY_SQUEEZER_TRANSITION_TYPE_CROSSFADE);
+       self->header_checking_label = adw_squeezer_new ();
+       adw_squeezer_set_xalign (ADW_SQUEEZER (self->header_checking_label), 0);
+       adw_squeezer_set_transition_type (ADW_SQUEEZER (self->header_checking_label), 
ADW_SQUEEZER_TRANSITION_TYPE_CROSSFADE);
 
        widget = gtk_label_new (_("Checking…"));
        gtk_widget_show (widget);
diff --git a/src/gs-updates-page.ui b/src/gs-updates-page.ui
index f2a203aeb..7288abcb0 100644
--- a/src/gs-updates-page.ui
+++ b/src/gs-updates-page.ui
@@ -66,11 +66,11 @@
           <object class="GtkStack" id="stack_updates">
             <property name="visible">True</property>
             <child>
-              <object class="HdyClamp">
+              <object class="AdwClamp">
                 <property name="visible">True</property>
                 <property name="valign">center</property>
-                <!-- We explicitly want to use the default HdyClamp sizes here,
-                     as does HdyStatusPage. -->
+                <!-- We explicitly want to use the default AdwClamp sizes here,
+                     as does AdwStatusPage. -->
                 <style>
                   <class name="status-page"/>
                 </style>
@@ -132,7 +132,7 @@
                   <class name="list-page"/>
                 </style>
                 <child>
-                  <object class="HdyClamp">
+                  <object class="AdwClamp">
                     <property name="visible">True</property>
                     <property name="maximum-size">600</property>
                     <property name="tightening-threshold">400</property>
@@ -180,7 +180,7 @@
                 </child>
                 <child>
 
-                  <!-- FIXME: This should be a HdyStatusPage but it doesn’t
+                  <!-- FIXME: This should be a AdwStatusPage but it doesn’t
                        currently support non-icon images
                        See https://gitlab.gnome.org/GNOME/libhandy/-/issues/448 -->
                   <object class="GtkScrolledWindow">
@@ -188,7 +188,7 @@
                     <property name="hscrollbar-policy">never</property>
                     <property name="propagate-natural-height">True</property>
                     <style>
-                      <class name="fake-hdy-status-page"/>
+                      <class name="fake-adw-status-page"/>
                     </style>
                     <child>
                       <object class="GtkBox">
@@ -196,7 +196,7 @@
                         <property name="orientation">vertical</property>
                         <property name="valign">center</property>
                         <child>
-                          <object class="HdyClamp">
+                          <object class="AdwClamp">
                             <property name="visible">True</property>
                             <child>
                               <object class="GtkBox">
@@ -257,7 +257,7 @@
               </packing>
             </child>
             <child>
-              <object class="HdyStatusPage">
+              <object class="AdwStatusPage">
                 <property name="visible">True</property>
                 <property name="icon_name">dialog-warning-symbolic</property>
                 <property name="title" translatable="yes">Use Mobile Data?</property>
@@ -276,7 +276,7 @@
               </packing>
             </child>
             <child>
-              <object class="HdyStatusPage">
+              <object class="AdwStatusPage">
                 <property name="visible">True</property>
                 <property name="icon_name">network-offline-symbolic</property>
                 <property name="title" translatable="yes">No Connection</property>
@@ -295,7 +295,7 @@
               </packing>
             </child>
             <child>
-              <object class="HdyStatusPage" id="updates_failed_page">
+              <object class="AdwStatusPage" id="updates_failed_page">
                 <property name="visible">True</property>
                 <property name="icon_name">action-unavailable-symbolic</property>
                 <property name="title" translatable="No">Error</property>
@@ -306,7 +306,7 @@
               </packing>
             </child>
             <child>
-              <object class="HdyStatusPage">
+              <object class="AdwStatusPage">
                 <property name="visible">True</property>
                 <property name="icon_name">action-unavailable-symbolic</property>
                 <property name="title" translatable="yes">Error</property>
diff --git a/src/gtk-style.css b/src/gtk-style.css
index 90c7f1dde..f47edd7aa 100644
--- a/src/gtk-style.css
+++ b/src/gtk-style.css
@@ -655,10 +655,10 @@ overlay > headerbar {
   border: none;
 }
 
-/* The following style are taken from libhandy's HdyPreferencesPage style, which
+/* The following style are taken from libhandy's AdwPreferencesPage style, which
  * implements the style for titled lists of lists.
  * FIXME: Drop these styles if the pages using it are ported to
- * HdyPreferencesPage or its successor in Libadwaita, if their clamp size can be
+ * AdwPreferencesPage or its successor in Libadwaita, if their clamp size can be
  * set as a property. */
 
 scrolledwindow.list-page > viewport > clamp {
@@ -700,17 +700,17 @@ scrolledwindow.list-page > viewport > clamp.large .section {
   margin-top: 18px;
 }
 
-/* The following style is taken from libhandy's HdyPreferencesGroup style, which
+/* The following style is taken from libhandy's AdwPreferencesGroup style, which
  * implements the style for titled and described sections with a list box.
- * FIXME: Drop this style if we use the successor of HdyPreferencesGroup in
+ * FIXME: Drop this style if we use the successor of AdwPreferencesGroup in
  * Libadwaita when porting to GTK 4. */
 
 .section > label:not(:first-child) { margin-top: 6px; }
 
 .section > box:not(:first-child) { margin-top: 12px; }
 
-/* The following style is taken from libhandy's HdyStatusPage style.
- * FIXME: Drop this style if HdyStatusPage or its GTK 4 successor allows setting
+/* The following style is taken from libhandy's AdwStatusPage style.
+ * FIXME: Drop this style if AdwStatusPage or its GTK 4 successor allows setting
  * a spinner and the updates spinner page can be ported to it. */
 
 clamp.status-page {
@@ -831,12 +831,12 @@ window.narrow .app-developer {
 
 .install-progress-label { font-size: smaller }
 
-/* FIXME: These are needed in the updates page until we can use HdyStatusPage
+/* FIXME: These are needed in the updates page until we can use AdwStatusPage
  * again. See the note in gs-updates-page.ui. */
-scrolledwindow.fake-hdy-status-page > viewport > box { margin: 36px 12px; }
-scrolledwindow.fake-hdy-status-page > viewport > box > clamp:not(:last-child) > box { margin-bottom: 36px; }
-scrolledwindow.fake-hdy-status-page > viewport > box > clamp > box > .icon:not(:last-child) { margin-bottom: 
36px; }
-scrolledwindow.fake-hdy-status-page > viewport > box > clamp > box > .title:not(:last-child) { 
margin-bottom: 12px; }
+scrolledwindow.fake-adw-status-page > viewport > box { margin: 36px 12px; }
+scrolledwindow.fake-adw-status-page > viewport > box > clamp:not(:last-child) > box { margin-bottom: 36px; }
+scrolledwindow.fake-adw-status-page > viewport > box > clamp > box > .icon:not(:last-child) { margin-bottom: 
36px; }
+scrolledwindow.fake-adw-status-page > viewport > box > clamp > box > .title:not(:last-child) { 
margin-bottom: 12px; }
 
 statuspage.icon-dropshadow image.icon {
   /* This copies the style of .icon-dropshadow from Adwaita. */


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/gs-featured-carousel.c b/src/gs-featured-carousel.c
index f1de11e83..a90da9e7c 100644
--- a/src/gs-featured-carousel.c
+++ b/src/gs-featured-carousel.c
@@ -24,11 +24,11 @@
 
 #include "config.h"
 
+#include <adwaita.h>
 #include <glib.h>
 #include <glib-object.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <handy.h>
 
 #include "gs-app-list.h"
 #include "gs-common.h"
@@ -44,7 +44,7 @@ struct _GsFeaturedCarousel
        GsAppList       *apps;  /* (nullable) (owned) */
        guint            rotation_timer_id;
 
-       HdyCarousel     *carousel;
+       AdwCarousel     *carousel;
        GtkButton       *next_button;
        GtkImage        *next_button_image;
        GtkButton       *previous_button;
@@ -70,17 +70,17 @@ static void
 show_relative_page (GsFeaturedCarousel *self,
                     gint                delta)
 {
-       gdouble current_page = hdy_carousel_get_position (self->carousel);
-       guint n_pages = hdy_carousel_get_n_pages (self->carousel);
+       gdouble current_page = adw_carousel_get_position (self->carousel);
+       guint n_pages = adw_carousel_get_n_pages (self->carousel);
        gdouble new_page;
        g_autoptr(GList) children = gtk_container_get_children (GTK_CONTAINER (self->carousel));
        GtkWidget *new_page_widget;
-       gint64 animation_duration_ms = hdy_carousel_get_animation_duration (self->carousel);
+       gint64 animation_duration_ms = adw_carousel_get_animation_duration (self->carousel);
 
        if (n_pages == 0)
                return;
 
        /* FIXME: This would be simpler if HdyCarousel had a way to scroll to
         * a page by index, rather than by GtkWidget pointer.
         * See https://gitlab.gnome.org/GNOME/libhandy/-/issues/413 */
        new_page = ((guint) current_page + delta + n_pages) % n_pages;
@@ -93,7 +93,7 @@ show_relative_page (GsFeaturedCarousel *self,
        if ((new_page == 0.0 && delta > 0) || (new_page == n_pages - 1 && delta < 0))
                animation_duration_ms = 0;
 
-       hdy_carousel_scroll_to_full (self->carousel, new_page_widget, animation_duration_ms);
+       adw_carousel_scroll_to_full (self->carousel, new_page_widget, animation_duration_ms);
 }
 
 static gboolean
@@ -280,7 +280,7 @@ carousel_clicked_cb (GsFeaturedCarousel *carousel,
        g_autoptr(GList) children = NULL;
 
        /* Get the currently visible tile. */
-       current_page = hdy_carousel_get_position (self->carousel);
+       current_page = adw_carousel_get_position (self->carousel);
        children = gtk_container_get_children (GTK_CONTAINER (self->carousel));
 
        current_tile = g_list_nth_data (children, current_page);
@@ -70,17 +70,17 @@ static void
                return;
 
-       /* FIXME: This would be simpler if HdyCarousel had a way to scroll to
+       /* FIXME: This would be simpler if AdwCarousel had a way to scroll to
         * a page by index, rather than by GtkWidget pointer.
         * See https://gitlab.gnome.org/GNOME/libhandy/-/issues/413 */
diff --git a/src/gs-repos-dialog.c b/src/gs-repos-dialog.c
index 1d6a82f48..7a2989a6d 100644
--- a/src/gs-repos-dialog.c
+++ b/src/gs-repos-dialog.c
@@ -22,7 +22,7 @@
 
 struct _GsReposDialog
 {
-       HdyWindow        parent_instance;
+       AdwWindow        parent_instance;
        GSettings       *settings;
        GsFedoraThirdParty *third_party;
        gboolean         third_party_enabled;
@@ -37,7 +37,7 @@ struct _GsReposDialog
        GtkWidget       *stack;
 };
 
-G_DEFINE_TYPE (GsReposDialog, gs_repos_dialog, HDY_TYPE_WINDOW)
+G_DEFINE_TYPE (GsReposDialog, gs_repos_dialog, ADW_TYPE_WINDOW)
 
 static void reload_third_party_repos (GsReposDialog *dialog);
 
@@ -62,7 +62,7 @@ G_DEFINE_AUTOPTR_CLEANUP_FUNC(InstallRemoveData, install_remove_data_free);
 static gboolean
 key_press_event_cb (GtkWidget            *sender,
                     GdkEvent             *event,
-                    HdyPreferencesWindow *self)
+                    AdwPreferencesWindow *self)
 {
        guint keyval;
        GdkModifierType state;
@@ -407,7 +407,7 @@ add_repo (GsReposDialog *dialog,
        section = g_hash_table_lookup (dialog->sections, origin_ui);
        if (section == NULL) {
                section = gs_repos_section_new (dialog->plugin_loader, FALSE);
-               hdy_preferences_group_set_title (HDY_PREFERENCES_GROUP (section),
+               adw_preferences_group_set_title (ADW_PREFERENCES_GROUP (section),
                                                 origin_ui);
                g_signal_connect_object (section, "remove-clicked",
                                         G_CALLBACK (repo_section_remove_clicked_cb), dialog, 0);
@@ -439,8 +439,8 @@ repos_dialog_compare_sections_cb (gconstpointer aa,
        if (res != 0)
                return res;
 
-       title_sort_key_a = gs_utils_sort_key (hdy_preferences_group_get_title (HDY_PREFERENCES_GROUP 
(section_a)));
-       title_sort_key_b = gs_utils_sort_key (hdy_preferences_group_get_title (HDY_PREFERENCES_GROUP 
(section_b)));
+       title_sort_key_a = gs_utils_sort_key (adw_preferences_group_get_title (ADW_PREFERENCES_GROUP 
(section_a)));
+       title_sort_key_b = gs_utils_sort_key (adw_preferences_group_get_title (ADW_PREFERENCES_GROUP 
(section_b)));
 
        return g_strcmp0 (title_sort_key_a, title_sort_key_b);
 }
@@ -515,10 +515,10 @@ get_sources_cb (GsPluginLoader *plugin_loader,
                                         G_CALLBACK (fedora_third_party_repos_switch_notify_cb), dialog, 0);
                gtk_widget_show (widget);
 
-               row = hdy_action_row_new ();
-               hdy_preferences_row_set_title (HDY_PREFERENCES_ROW (row), _("Enable New Repositories"));
-               hdy_action_row_set_subtitle (HDY_ACTION_ROW (row), _("Turn on new repositories when they are 
added."));
-               hdy_action_row_set_activatable_widget (HDY_ACTION_ROW (row), widget);
+               row = adw_action_row_new ();
+               adw_preferences_row_set_title (ADW_PREFERENCES_ROW (row), _("Enable New Repositories"));
+               adw_action_row_set_subtitle (ADW_ACTION_ROW (row), _("Turn on new repositories when they are 
added."));
+               adw_action_row_set_activatable_widget (ADW_ACTION_ROW (row), widget);
                gtk_container_add (GTK_CONTAINER (row), widget);
                gtk_widget_show (row);
 
@@ -534,15 +534,15 @@ get_sources_cb (GsPluginLoader *plugin_loader,
                                _("Additional repositories from selected third parties — %s."),
                                anchor);
 
-               widget = hdy_preferences_group_new ();
-               hdy_preferences_group_set_title (HDY_PREFERENCES_GROUP (widget),
+               widget = adw_preferences_group_new ();
+               adw_preferences_group_set_title (ADW_PREFERENCES_GROUP (widget),
                                                 _("Fedora Third Party Repositories"));
 /* HdyPreferencesGroup:use-markup doesn't exist before 1.3.90, configurations
  * where GNOME 41 will be used and Libhandy 1.3.90 won't be available are
  * unlikely, so let's just ignore the description in such cases. */
-#if HDY_CHECK_VERSION(1, 3, 90)
-               hdy_preferences_group_set_description (HDY_PREFERENCES_GROUP (widget), hint);
-               hdy_preferences_group_set_use_markup (HDY_PREFERENCES_GROUP (widget), TRUE);
+#if ADW_CHECK_VERSION(1, 3, 90)
+               adw_preferences_group_set_description (ADW_PREFERENCES_GROUP (widget), hint);
+               adw_preferences_group_set_use_markup (ADW_PREFERENCES_GROUP (widget), TRUE);
 #endif
 
                gtk_widget_show (widget);
@@ -733,7 +733,7 @@ gs_repos_dialog_init (GsReposDialog *dialog)
           %s gets replaced by the name of the actual distro, e.g. Fedora. */
        label_empty_text = g_strdup_printf (_("These repositories supplement the default software provided by 
%s."),
                                            os_name);
-       hdy_status_page_set_description (HDY_STATUS_PAGE (dialog->status_empty), label_empty_text);
+       adw_status_page_set_description (ADW_STATUS_PAGE (dialog->status_empty), label_empty_text);
 }
 
 static void
@@ -534,15 +534,15 @@ get_sources_cb (GsPluginLoader *plugin_loader,
                                                 _("Fedora Third Party Repositories"));
-/* HdyPreferencesGroup:use-markup doesn't exist before 1.3.90, configurations
+/* AdwPreferencesGroup:use-markup doesn't exist before 1.3.90, configurations
  * where GNOME 41 will be used and Libhandy 1.3.90 won't be available are
  * unlikely, so let's just ignore the description in such cases. */